<?

/*

VoxPopuli

Copyright (c) 2009-2011, EldoS Corporation

For licensing and distribution terms visit http://www.eldos.com/

*/

require_once("vox-classes.php");

require_once("site_specific/vox-config.php");

include_once("site_specific/vox-messages.php");
require_once("site_specific/vox-rewrites.php");

require_once("vox-ui.php");


// ---------------------------------------------------------------------
// Helper functions
// ---------------------------------------------------------------------

function log_event($eventType, $eventDetails, $ideaId)
{
	$entry = new voxLogEntry();
	$entry->time = date("Y-m-d");
	$entry->userId = vox_user_get_id();
	$entry->eventType = $eventType;
	$entry->eventDetails = $eventDetails;
	$entry->ideaId = $ideaId;
	$entry->add();

}

function vox_view_idealist_xml($listing)
{
	global $VOX_MESSAGES, $vox_language, $vox_view_show_votes, $vox_view_item_count, $vox_view_show_recent;

	$aCount = $listing["count"];
	echo "<count>" . $aCount . "</count>";
	
	echo "<ideas>";
	
	for ($i = 0; $i < $aCount; $i++)
	{
		echo "<idea>\n";
		echo "<id>" . $listing[$i]["id"] . "</id>\n";
		
		echo "<ideastatus>" . $listing[$i]["ideastatus"] . "</ideastatus>\n";
		echo "<ideastatusname>" . $listing[$i]["ideastatusname"] . "</ideastatusname>\n";
		
		if ($vox_view_show_votes) 
		{
			if (array_key_exists("uservote", $listing[$i]))
				echo "<uservote>" . $listing[$i]["uservote"] . "</uservote>";
			
			echo "<votesfor>" . $listing[$i]["votesfor"] . "</votesfor>";
			if (array_key_exists("votesagainst", $listing[$i]))
				echo "<votesagainst>" . $listing[$i]["votesagainst"] . "</votesagainst>";
		}
		
		echo "<title>" . $listing[$i]["title"] . "</title>";
		echo "</idea>\n";
	}
	echo "</ideas>";
}

function vox_output_idealist_xml($listing, $category, $fetchdesc = false)
{
	global $VOX_MESSAGES, $vox_language;

	$showCategory = $category == -1;
	
	echo "<authenticated>" . $listing["authenticated"] . "</authenticated>";
	echo "<totalcount>" . $listing["totalcount"] . "</totalcount>";
	echo "<count>" . $listing["count"] . "</count>";
	
	echo "<ideas>";
	
	for ($i = 0; $i < $listing["count"]; $i++)
	{
		echo "<idea>\n";
		echo "<id>" . $listing[$i]["id"] . "</id>\n";
		
		echo "<userid>" . $listing[$i]["userId"] . "</userid>\n";
		echo "<username>" . $listing[$i]["username"] . "</username>\n";
		echo "<usercontact>" . $listing[$i]["usercontact"] . "</usercontact>\n";
		echo "<dateadded>" . $listing[$i]["dateadded"] . "</dateadded>\n";
		echo "<datestatus>" . $listing[$i]["datestatus"] . "</datestatus>\n";
		
		echo "<category>" . $listing[$i]["category"] . "</category>\n";
		if (array_key_exists("commenturl", $listing[$i]))
		{
				echo "<commenturl>" . $listing[$i]["commenturl"] . "</commenturl>\n";
				echo "<comments>" . $listing[$i]["comments"] . "</comments>\n";
				echo "<newcommenturl>" . $listing[$i]["newcommenturl"] . "</newcommenturl>\n";
		}
		
		echo "<ideastatus>" . $listing[$i]["ideastatus"] . "</ideastatus>\n";
		echo "<ideastatusname>" . $listing[$i]["ideastatusname"] . "</ideastatusname>\n";
		
		if (array_key_exists("uservote", $listing[$i]))
			echo "<uservote>" . $listing[$i]["uservote"] . "</uservote>";
		
		echo "<votesfor>" . $listing[$i]["votesfor"] . "</votesfor>";
		if (array_key_exists("votesagainst", $listing[$i]))
			echo "<votesagainst>" . $listing[$i]["votesagainst"] . "</votesagainst>";
		
		echo "<title>" . $listing[$i]["title"] . "</title>";
		echo "</idea>\n";
	}
	echo "</ideas>";
}

function vox_output_category_list_xml($listing)
{
	global $VOX_MESSAGES, $vox_language;
	echo "<categories>\n";
	$count = count($listing);
	for ($i = 0; $i < $count; $i++)
	{
		echo "<category>\n";
		echo "<name>" . $listing[$i]["name"] . "</name>";
		echo "<forumid>" . $listing[$i]["forumid"] . "</forumid>";
		echo "<forumurl>" . $listing[$i]["forumurl"] . "</forumurl>";
		echo "</category>\n";
	}
	echo "</categories>";
	
}

// ---------------------------------------------------------------------
// Main functionality
// ---------------------------------------------------------------------

function vox_view_ideas($category)
{
	global $VOX_MESSAGES, $VOX_IDEA_STATUS, $vox_language, $vox_view_show_votes, $vox_view_item_count, $vox_view_show_recent;
	if ($category == -1)
	{
		$category = 1;
	}
	$cat = new voxCategory();
	
	$cat->id = $category;
	$got = $cat->get();	
	if ($got)
	{
		$ideas = voxIdea::getView($category, $vox_view_item_count, $vox_view_show_recent);
		
		vox_report_success();
		
		$aCount = count($ideas);
		
		// output the resulting data
		
		$listing = array();
		$listing["count"] = $aCount;
		
		for ($i = 0; $i < $aCount; $i++)
		{
			$idea = $ideas[$i];
			$listing[$i]["id"] = $idea->id;
						
			$listing[$i]["ideastatus"] = $idea->status;
			$listing[$i]["ideastatusname"] = $VOX_IDEA_STATUS[$idea->status][$vox_language];
			
			if ($vox_view_show_votes) 
			{
				$listing[$i]["votesfor"] = $idea->votesFor;
				if ($GLOBALS["vox_allow_votes_against"])
					$listing[$i]["votesagainst"] = $idea->votesAgainst;
			}
			
			$listing[$i]["title"] = vox_format_texts($idea->title);			
		}
		if ($GLOBALS["vox_xml_output"])
			vox_view_idealist_xml($listing);
		else
			vox_view_idealist_html($listing);
	}	
	else
		vox_report_error($VOX_MESSAGES["vox_msg_invalid_parameter"]);
}

function vox_view_ideas_rawlist($category)
{
	global $VOX_MESSAGES, $VOX_IDEA_STATUS, $vox_language, $vox_view_show_votes, $vox_view_item_count, $vox_view_show_recent;
	if ($category == -1)
	{
		$category = 1;
	}
	$cat = new voxCategory();
	
	$cat->id = $category;
	$got = $cat->get();	
	if ($got)
	{
		$ideas = voxIdea::getView($category, 0, true);
		
		vox_report_success();
		
		$aCount = count($ideas);
		
		// output the resulting data
		
		$listing = array();
		$listing["count"] = $aCount;
		
		for ($i = 0; $i < $aCount; $i++)
		{
			$idea = $ideas[$i];
			$listing[$i]["id"] = $idea->id;
            						
			$listing[$i]["ideastatus"] = $idea->status;
			$listing[$i]["ideastatusname"] = $VOX_IDEA_STATUS[$idea->status][$vox_language];
			
			if ($vox_view_show_votes) 
			{
				$listing[$i]["votesfor"] = $idea->votesFor;
				if ($GLOBALS["vox_allow_votes_against"])
					$listing[$i]["votesagainst"] = $idea->votesAgainst;
			}
			
			$listing[$i]["title"] = vox_format_texts($idea->title);
			$listing[$i]["desc"] = vox_format_texts($idea->desc);
		}
		vox_rawlist_html($listing);
	}	
	else
		vox_report_error($VOX_MESSAGES["vox_msg_invalid_parameter"]);
}

function vox_list_ideas($category, $startfrom, $number, $onlyuser, $onlyopen, $onlystatus, $sortorder, $searchterm, $fetchdesc = false)
{
	global $VOX_MESSAGES, $VOX_IDEA_STATUS, $vox_language;
			
	// check for valid status
	if ($onlystatus != 0 && ($onlystatus < VOX_STATUS_FIRST || $onlystatus > VOX_STATUS_LAST))
		vox_report_error($VOX_MESSAGES["vox_msg_invalid_parameter"]);
	else
	{
		// validate parameters		
		
		$onlyopen = ($onlyopen == 1);
			
		if ($startfrom < 0) 
			$startfrom = 0;

		if ($number == 0)
			$number = $GLOBALS["vox_default_ideas_per_page"];
		else
		if ($number > 40 || $number < 0)
			$number = 20;

		// prevent possible access permission violations
		if (!vox_user_is_admin() || !(vox_user_has_rights($category, VOX_OPERATION_MODERATE_IDEA) && $category != -1))
		{
			if ($category == -1)
				$category = 1;
			if (
				($onlyuser) || 
				($onlystatus == VOX_STATUS_COMPLETE) ||
				($onlyopen == true)
				)
			{
				// do nothing
			}
			else
			{				
				$onlyopen = true;
				$onlystatus = 0;
				$onlyuser = 0;
			}			
		}
		
		if ($searchterm == "Search") 
			$searchterm = "";
		else
			$searchterm = trim($searchterm);
		$totalrows = 0;
		
		$aCat = $category;
		$cat = new voxCategory();
			
		if ($aCat >= 0)
		{
			$cat->id = $aCat;
			$got = $cat->get();	
		}

		if ($onlyuser)
			$onlyuser = vox_user_get_id();

		// grab the ideas from the DB
		$ideas = voxIdea::getRange($startfrom * $number, $number, $aCat, $onlyuser, $onlyopen, $onlystatus, $sortorder, $searchterm, $totalrows);
		
		vox_report_success();
		
		$aCount = count($ideas);
		
		$currentUser = vox_user_get_id();
		
		$authenticated = (($currentUser  > 0) ? "yes" : "no");
		
		// output the resulting data
		
		$listing = array();
		
		$listing["authenticated"] = $authenticated;
		$listing["totalcount"] = $totalrows;
		$listing["count"] = $aCount;
		
		$listing["startfrom"] = $startfrom * $number;
		$listing["number"] = $number;
		$listing["search"] = $searchterm;
		$listing["sortorder"] = $sortorder;
		
		for ($i = 0; $i < $aCount; $i++)
		{
			$idea = $ideas[$i];
			$listing[$i]["id"] = $idea->id;
			
			$username = "";
			$usercontact = "";
			if ($idea->userId > 0)
			{			
				$username = vox_user_get_name_by_id($idea->userId);
				$usercontact = vox_user_get_contact_url_by_id($idea->userId);
			}	
			if ($username == "")
				$username = $idea->name;
			$listing[$i]["userid"] = $idea->userId;
			$listing[$i]["username"] = $username;
			$listing[$i]["usercontact"] = $usercontact;
			$listing[$i]["dateadded"] = $idea->dateAdded;
			$listing[$i]["datestatus"] = $idea->dateStatus;
			
			
			$cattitle = "";
			if ($aCat == -1)
			{
				$cat->id = $idea->category;
				$got = $cat->get();					
			}
			if ($got)
			{
				$listing[$i]["category"] = $cat->name;
				
				if ($cat->forumId != "" && $idea->forumId != "")
				{
					$listing[$i]["comments"] = vox_forum_get_comment_count($cat->forumId, $idea->forumId);
					$listing[$i]["commenturl"] = vox_forum_get_topic_url($cat->forumId, $idea->forumId);
					$listing[$i]["newcommenturl"] = vox_forum_get_new_comment_url($cat->forumId, $idea->forumId);
				}
			}
			$listing[$i]["ideastatus"] = $idea->status;
			$listing[$i]["ideastatusname"] = $VOX_IDEA_STATUS[$idea->status][$vox_language];
					
			$vote = new voxVote();
			$vote->userId = $currentUser;
			$vote->ideaId = $idea->id;
			if ($vote->exists($userVote))
			{
				$listing[$i]["uservote"] = $userVote;
			}
			
			$listing[$i]["votesfor"] = $idea->votesFor;
			if ($GLOBALS["vox_allow_votes_against"])
				$listing[$i]["votesagainst"] = $idea->votesAgainst;
				
			$listing[$i]["title"] = vox_format_texts($idea->title);
			$listing[$i]["desc"] = vox_format_texts($idea->desc);
		}
		
		if ($GLOBALS["vox_xml_output"])
			vox_output_idealist_xml($listing, $aCat, $fetchdesc);
		else
			vox_output_idealist_html($listing, $aCat, $fetchdesc);
	}
}

function vox_update_idea($id, $title, $desc, $name, $email)
{
	global $VOX_MESSAGES, $vox_language;
	
	$idea = new voxIdea();
	$idea->id = $id;
	if ($idea->get())
	{
		$category = $idea->category;
		
		if (!vox_user_is_admin() && !vox_user_has_rights($category, VOX_OPERATION_EDIT_IDEA))
		{
			vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_change_idea"]);
		}
		else
		{
			$succ = false;
			
			$idea->title = $title;
			$idea->desc = $desc;
			$idea->name = $name;
			$idea->email = $email;	
			$succ = $idea->change();
			if ($succ)
				vox_report_success($VOX_MESSAGES["vox_msg_idea_change_success"]);
			else
				vox_report_error($VOX_MESSAGES["vox_msg_idea_change_failed"]);
				
		}
	}
	else
		vox_report_error($VOX_MESSAGES["vox_msg_idea_not_found"]);
	vox_show_continue_button_html();
}

function vox_move_idea($id, $newCategory)
{
	global $VOX_MESSAGES, $vox_language;
	
	$idea = new voxIdea();
	$idea->id = $id;
	if ($idea->get())
	{
		$category = $idea->category;
		
		if (!vox_user_is_admin() && !(vox_user_has_rights($category, VOX_OPERATION_MOVE_IDEA_FROM) && vox_user_has_rights($newCategory, VOX_OPERATION_MOVE_IDEA_TO)))
		{
			vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_move_idea"]);
		}
		else
		{
			$succ = false;
			
			$idea->category = $newCategory;
			$succ = $idea->change();
			if ($succ)
				vox_report_success($VOX_MESSAGES["vox_msg_idea_move_success"]);
			else
				vox_report_error($VOX_MESSAGES["vox_msg_idea_move_failed"]);				
		}
	}
	else
		vox_report_error($VOX_MESSAGES["vox_msg_idea_not_found"]);
	vox_show_continue_button_html();
}

function vox_submit_idea($category, $title, $desc, $name, $email)
{
	global $VOX_MESSAGES, $vox_language, $vox_notify_admin_id, $vox_notify_admin_email;

	$userId = vox_user_get_id();
	if ($GLOBALS["vox_allow_submit_without_login"] == false && $userId == 0)
	{
		vox_report_error($VOX_MESSAGES["vox_msg_not_logged_on"]);
	}
	else
	if ($title == "" && $desc == "")
	{
		vox_report_error($VOX_MESSAGES["vox_msg_no_title"]);
	}
	else
	{
		if ($title == "")
			$title = "(untitled)";
		$idea = new voxIdea();
		$idea->dateAdded = date("Y-m-d");
		$idea->dateStatus = $idea->dateAdded;
		$idea->userId = $userId;
		$idea->title = $title;
		$idea->desc = $desc;
		$idea->category = $category;

		$idea->name = vox_user_get_name_by_id($userId);
		if ($idea->name == "" && $name != "")
			$idea->name = $name;
		$idea->email = $email;
	
		$idea->status = VOX_STATUS_PENDING;
		if ($idea->add())
		{

			log_event(VOX_EVENT_IDEA_ADDED, 0, $idea->id);

			// we need to notify the administrator that the new idea has been posted
			$cattitle = "";

			$cat = new voxCategory();
			$cat->id = $category;
			
			if ($cat->get())
				$cattitle = $cat->name;
			
			vox_notify_admin_idea_posted($idea->id, $title, $desc, $userId, $name, $email, $cattitle, $vox_notify_admin_id, $vox_notify_admin_email, $GLOBALS["vox_widget_location"]);
			
			if (vox_user_requires_moderation($userId) == false || vox_user_is_admin() || vox_user_has_rights($category, VOX_OPERATION_APPROVE_IDEA))
			{
				vox_process_idea($idea->id, VOX_STATUS_NEW, "", true, false, false);
				vox_report_success($VOX_MESSAGES["vox_msg_idea_adding_success"]);
			}
			else
				vox_report_success($VOX_MESSAGES["vox_msg_idea_adding_success_mod"]);
		}
		else
			vox_report_error($VOX_MESSAGES["vox_msg_idea_adding_failed"]);
	}
	vox_show_continue_button_html();
}

function vox_process_idea($id, $status, $comment, $sendupdate, $validate, $showstatuschange = true)
{
	global $VOX_MESSAGES, $vox_language;
	
	$idea = new voxIdea();
	$idea->id = $id;
	if ($idea->get())
	{	
		$category = $idea->category;
		if ($validate && !vox_user_is_admin() && !vox_user_has_rights($category, VOX_OPERATION_CHANGE_IDEA_STATUS))
			vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_change_status"]);
		else
		if ($status < VOX_STATUS_FIRST || $status > VOX_STATUS_LAST)
			vox_report_error($VOX_MESSAGES["vox_msg_invalid_parameter"]);
		else
		{
			// modify the record
			$oldstatus = $idea->status;
			$idea->status = $status;
			$idea->dateStatus = date("Y-m-d");
			if ($idea->change())
			{	
				log_event(VOX_EVENT_IDEA_STATUS, $status, $id);

				// get the name of the category to be used in notifications
				$cattitle = "";
				$forumId = 1;

				$cat = new voxCategory();
				$cat->id = $idea->category;
				if ($cat->get())
				{
					$cattitle = $cat->name;
					$forumId = $cat->forumId;
				}
				else
				{
					$forumId = 0;
				}

				// create new topic in the forum and add it's id						
				if ($oldstatus == VOX_STATUS_PENDING && $status == VOX_STATUS_NEW)
				{
					$idea->forumId = vox_forum_create_topic($forumId, $cattitle, $idea->id, $idea->title, $idea->desc, $idea->userId, $idea->name, $idea->email, $GLOBALS["vox_widget_location"]);
					if ($idea->forumId != "")
						$idea->change();						
				}

				// take proper action such as notify about status update
				
				{

					// 1. If the idea was rejected
					if ($status == VOX_STATUS_REJECTED)
					{
						if ($GLOBALS["vox_notify_users_by_email"] && $sendupdate)
							vox_notify_idea_rejected($id, $idea->title, $idea->userId, $cattitle, $comment);
					}
					else
					// 2. If the idea was accepted
					if ($oldstatus == VOX_STATUS_PENDING && $status == VOX_STATUS_NEW)
					{					
						if ($GLOBALS["vox_notify_users_by_email"] && $sendupdate)
							vox_notify_idea_accepted($id, $idea->title, $idea->userId, $cattitle, $comment);
					}
					else
					// 3. If the idea was taken for work
					if ((($oldstatus == VOX_STATUS_NEW) || ($oldstatus == VOX_STATUS_PLANNED)) && $status == VOX_STATUS_INWORK)
					{
						vox_idea_to_work($id, $idea->title, $idea->desc, $idea->userId, $idea->category, $cattitle);
						if ($GLOBALS["vox_notify_users_by_email"] && $sendupdate)
							vox_notify_idea_to_work($id, $idea->title, $idea->userId, $cattitle, $comment);
						
						vox_forumnotify_idea_to_work($cat->forumId, $idea->forumId, $idea->title, $comment);
					}
					else
					// 4. If the idea was taken for work
					if ($oldstatus == VOX_STATUS_NEW && $status == VOX_STATUS_PLANNED)
					{
						if ($GLOBALS["vox_notify_users_by_email"] && $sendupdate)
							vox_notify_idea_planned($id, $idea->title, $idea->userId, $cattitle, $comment);

						vox_forumnotify_idea_planned($cat->forumId, $idea->forumId, $idea->title, $comment);
					}
					else
					// 5. If the idea was completed
					if ((($oldstatus == VOX_STATUS_INWORK) || ($oldstatus == VOX_STATUS_PLANNED)) && $status == VOX_STATUS_COMPLETE)
					{
						if ($GLOBALS["vox_notify_users_by_email"] && $sendupdate)
						vox_notify_idea_complete($id, $idea->title, $idea->userId, $cattitle, $comment);
						vox_forumnotify_idea_complete($cat->forumId, $idea->forumId, $idea->title, $comment);
					}					
				}
				if ($showstatuschange)
					vox_report_success($VOX_MESSAGES["vox_msg_status_change_success"]);
			}
			else
				vox_report_error($VOX_MESSAGES["vox_msg_status_change_failed"]);
		}
	}
	else
		vox_report_error($VOX_MESSAGES["vox_msg_idea_not_found"]);

	if ($showstatuschange)
		vox_show_continue_button_html();
}

function vox_vote($id, $voteValue)
{
	global $VOX_MESSAGES, $vox_language;

	if ($voteValue > 1 || $voteValue < 0 || ($GLOBALS["vox_allow_votes_against"] == false && $voteValue == 0))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_vote_failed"]);
		return;
	}

	$userId = vox_user_get_id();
	
	$vote = new voxVote();

	vox_check_can_vote($userId, $id, $_COOKIE["VOX_ID"], $can_vote_for, $can_vote_against, $hide_votes);
	if (($voteValue == 1 && !$can_vote_for) || ($voteValue == 0 && !$can_vote_against))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_cant_vote"]);
	}
	else
	{	
		if (vox_check_vote($userId, $id, $_COOKIE["VOX_ID"], $prevvote, $vote))
		{		
			if ($voteValue == $prevvote)
			{				
				vox_report_error($VOX_MESSAGES["vox_msg_already_voted"]);
			}
			else
			{
				log_event(VOX_EVENT_VOTE, $vote, $id);

				$vote->remove();
				$idea = new voxIdea();
				$idea->id = $id;
				$idea->removeVoteFromCache($prevvote);
				
				if ($GLOBALS["vox_confirm_vote"])
					$msg = $VOX_MESSAGES["vox_msg_vote_success"];
				else
					$msg = "";
				vox_report_success($msg);
				vox_show_continue_button_html();
			}
		}
		else
		{
			$vote->value = $voteValue;
			if ($vote->add())
			{
				log_event(VOX_EVENT_VOTE, $voteValue, $id);

				$idea = new voxIdea();
				$idea->id = $id;
				$idea->addVoteToCache($voteValue);
				if ($GLOBALS["vox_confirm_vote"])
					$msg = $VOX_MESSAGES["vox_msg_vote_success"];
				else
					$msg = "";
				vox_report_success($msg);
				vox_show_continue_button_html();
			}
			else
			{
				vox_report_error($VOX_MESSAGES["vox_msg_vote_failed"]);				
			}
		}			
	}	
}

function vox_delete_idea($id, $confirm)
{
	global $VOX_MESSAGES, $vox_language;
	
	$idea = new voxIdea();
	$idea->id = $id;
	if ($idea->get())
	{
		$category = $idea->category;
		
		// Now check permissions. Idea can be deleted by administrator
		// or by the user while the idea is in VOX_STATUS_PENDING stauts
		$userId = vox_user_get_id();
		if ($userId == 0)
		{
			vox_report_error($VOX_MESSAGES["vox_msg_not_logged_on"]);
		}
		else
		if (!vox_user_is_admin() && $idea->userId != $userId && !vox_user_has_rights($category, VOX_OPERATION_DELETE_IDEA)) 
		{
			vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_delete_others_item"]);
		}
		else
		if (vox_user_is_admin() || vox_user_has_rights($category, VOX_OPERATION_DELETE_IDEA) || $idea->status == VOX_STATUS_PENDING)
		{
			if ($confirm == 0 && $GLOBALS["vox_confirm_deletions"] == true)
			{
				vox_show_query_html($VOX_MESSAGES["vox_msg_confirm_delete_idea"], "voxUI.deleteIdea(" . $id . ", 1);", "voxUI.refreshIdeaList();");
				return;
			}
			else
			{
				$idea->remove();
				log_event(VOX_EVENT_IDEA_DELETED, 0, $idea->id);

				vox_report_success($VOX_MESSAGES["vox_msg_idea_delete_success"]);
			}
		}
		else
		{
			// the idea has been processed and the user is not an admin
			vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_delete_processed_item"]);
		}
		
	}	
	else
		vox_report_error($VOX_MESSAGES["vox_msg_idea_not_found"]);
		
	vox_show_continue_button_html();
}

function vox_get_idea_description($id)
{
	global $VOX_MESSAGES, $vox_language;

	$idea = new voxIdea();
	$idea->id = $id;
	if ($idea->get())
		echo $idea->desc;		
	else
		vox_report_error($VOX_MESSAGES["vox_msg_idea_not_found"]);
}

function vox_show_idea_form($ideaId)
{
	global $VOX_MESSAGES;
	
	if ($ideaId > 0)
	{	
		$idea = new voxIdea();
		$idea->id = $ideaId;
		if ($idea->get())
		{
			$category = $idea->category;
			if (!vox_user_is_admin() && !vox_user_has_rights($category, VOX_OPERATION_EDIT_IDEA))
			{
				vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_change_idea"]);
				vox_show_continue_button_html();			
				return;
			}
		}
	}
	vox_show_idea_form_html($ideaId);
}

function vox_show_move_form($ideaId)
{
	global $VOX_MESSAGES;
	
	if ($ideaId > 0)
	{	
		$idea = new voxIdea();
		$idea->id = $ideaId;
		if ($idea->get())
		{
			$category = $idea->category;
			if (!vox_user_is_admin() && !vox_user_has_rights($category, VOX_OPERATION_MOVE_IDEA_FROM))
			{
				vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_move_idea"]);
				vox_show_continue_button_html();			
				return;
			}
		}
	}
	vox_show_move_form_html($ideaId);
}

function vox_update_category($id, $title, $forumId)
{
	global $VOX_MESSAGES;
	
	if (!vox_user_is_admin() && !vox_user_has_rights($id, VOX_OPERATION_EDIT_CATEGORY))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_change_category"]);
	}
	else
	{
		$cat = new voxCategory();
		$cat->id = $id;
		if ($cat->get())
		{
			$cat->name = $title;
			$cat->forumId = $forumId;
			if ($cat->change())
			{
				vox_report_success($VOX_MESSAGES["vox_msg_cat_change_success"]);
			}
			else
				vox_report_error($VOX_MESSAGES["vox_msg_cat_change_failed"]);
		}
		else
			vox_report_error($VOX_MESSAGES["vox_msg_cat_change_failed"]);
	}	
	vox_show_continue_button_html();
}

function vox_add_category($title, $forumId)
{
	global $VOX_MESSAGES;
	if (!vox_user_is_admin()&& !vox_user_has_rights($id, VOX_OPERATION_ADD_CATEGORY))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_add_category"]);
	}
	else
	{
		$cat = new voxCategory();
		$cat->name = $title;
		$cat->forumId = $forumId;
		if ($cat->add())
		{
			vox_report_success($VOX_MESSAGES["vox_msg_cat_adding_success"]);
		}
		else
			vox_report_error($VOX_MESSAGES["vox_msg_cat_adding_failed"]);
	}
	vox_show_continue_button_html();
}

function vox_delete_category($id, $confirm)
{
	global $VOX_MESSAGES, $vox_language;

	if (!vox_user_is_admin() && !vox_user_has_rights($id, VOX_OPERATION_DELETE_CATEGORY))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_delete_category"]);
	}
	else
	{
		if ($confirm == 0 && $GLOBALS["vox_confirm_deletions"] == true)
		{
			vox_show_query_html($VOX_MESSAGES["vox_msg_confirm_delete_category"], "voxUI.deleteCategory(" . $id . ", 1);", "voxUI.refreshIdeaList();");
			return;
		}
		else
		{
			$cat = new voxCategory();
			$cat->id = $id;
			if ($cat->remove())
				vox_report_success($VOX_MESSAGES["vox_msg_cat_delete_success"]);
			else
				vox_report_error($VOX_MESSAGES["vox_msg_cat_delete_failed"]);
		}
	}	
	vox_show_continue_button_html();	
}

function vox_list_categories()
{
	global $VOX_MESSAGES, $vox_language;
	
	$categories = voxCategory::getAll();
	
	$listing = array();
	
	$aCount = count($categories);
	
	for ($i = 0; $i < $aCount; $i++)
	{
		$category = $categories[$i];
		
		$listing[$i]["id"] = $category->id;
		$listing[$i]["name"] = $category->name;
		$listing[$i]["forumid"] = $category->forumId;
		$listing[$i]["forumurl"] = vox_forum_get_url($category->forumId);
	}
	
	if ($GLOBALS["vox_xml_output"])
		vox_output_category_list_xml($listing);
	else
		vox_output_category_list_html($listing);
}

function vox_show_cat_form($catId)
{
	global $VOX_MESSAGES;
	
	if (!vox_user_is_admin() && !vox_user_has_rights($id, VOX_OPERATION_EDIT_CATEGORY))
	{
		vox_report_error($VOX_MESSAGES["vox_msg_action_may_not_change_category"]);
		vox_show_continue_button_html();
	}
	else
		vox_show_cat_form_html($catId);
}

?>