<?

/*

VoxPopuli

Copyright (c) 2009-2011, EldoS Corporation

For licensing and distribution terms visit http://www.eldos.com/

*/

/*

Requests:

* All. 
    Parameters:
	- voxlang (optional, default en) - use text messages in specified language

0. None - sends widget box HTML
	
1. list - retrieves ideas from the DB using specified criteria
	Parameters:
    - fetchdesc [0/1] (optional, default 0) - specifies whether descriptions are fetched immediately with the listing. This is used when "wide" css is used 
	- category (#) (optional, default 0) - the id of the category to show. -1 denotes Admin mode (ideas from all categories are shown)
	- startfrompage (#) (optional, default 0) - starting page index
	- number (#) (optional, default 20) - number of ideas to show
	- onlyuser (#) (optional, default 0) - specifies if only the ideas of the user with given ID are shown
	- onlyopen [0/1] (optional, default 0) - specifies whether only open or all ideas are shown
	- onlystatus (#) (optional) - specifies whether only ideas with specified status (such as pending) are shown
	- searchterm (optional) - specifies the search term that limits the request
		
2. submit - submits new idea
	Parameters:
	- category (#) (optional, default 0) - the id of the category to which new idea belongs
	- title - title of the new idea.
	- description - description of the new idea.
	- name (optional) - Name of the user. Required, if the user is not logged in
	- e-mail (optional) - e-mail address of the user. Required, if the user is not logged in
	
3. update - updates an idea
	Parameters:
	- ID (#) - the id of the idea
	- title - new title of the idea.
	- description - new description of the idea.
	- name (optional) - Name of the user. 
	- e-mail (optional) - e-mail address of the user. 
	Requirements:
	The idea can be updated only by the administrator

4. setstatus - sets the status of the idea
	Parameters:
	- ID (#) - ID of the idea to be voted for.
	- status (#) - specifies the status code of the idea
	- comment (optional) - admin's comment
	- sendupdate (0, 1) - notify the user about change
	Requirements:
	The idea can be processed only by the administrator

5. todo - adds the idea to todo list
	Parameters:
	- ID (#) - ID of the idea to be voted for.
	Requirements:
	The idea can be processed only by the administrator
	
6. vote - gives a vote to idea
	Parameters:
	- ID (#) - ID of the idea to be voted for.
	- value (0, 1) - the value of the vote

7. delete - deletes an idea and all of it's votes
	Parameters:
	- ID (#) - ID of the idea to be deleted.
	- confirm (0, 1) - specifies, that the operation has been confirmed by the user
	Requirements:
	The idea can be deleted only by the author or administrator

8. desc - retrieves description of the idea
	Parameters:
	- ID (#) - ID of the idea whose description is to be retrieved.

9. cat_list - retrieves the list of categories

10. cat_delete - deletes the category
	Parameters:
	- ID (#) - ID of the category being deleted
	- confirm (0, 1) - specifies, that the operation has been confirmed by the user
	Requirements:
	The category can be deleted only by the administrator
	
11. cat_submit - creates the category
	Parameters:
	- title - title of the category.
	- forumid - id of the forum
	Requirements:
	The category can be created only by the administrator

12. cat_update - updates the category
	Parameters:
	- ID (#) - id of the forum
	- title - title of the category.
	- forumid (optional) - id of the forum
	Requirements:
	The category can be updated only by the administrator

13. getideaform - retrieves idea submission form from the server
	Parameters:
	- ID (#) (optional) - if present, specifies ID of the existing idea to edit
	Requirements:
	The ID can be specified only by the administrator

14. getcatform - retrieves category submission form from the server
	Parameters:
	- ID (#) (optional) - if present, specifies ID of the existing category to edit
	Requirements:
	The ID can be specified only by the administrator
	
15. view - displays the top X items in "view-only" (or "preview") mode  
	
*/

require_once("site_specific/vox-config.php");
include_once("site_specific/prolog.php");

include_once("site_specific/vox-messages.php");
require_once("vox-main.php");

$action=$_REQUEST["action"];

$vox_script_location = $_REQUEST["loc"];

// Determine the language for text messages
$curlang = strtolower(trim($_REQUEST["voxlang"]));

if ($vox_message_language_defined[$curlang] == "")
	$vox_language = "en";
else
	$vox_language = $curlang;

$vox_widget_location = urldecode(trim($_REQUEST["widgetloc"]));
	
// Call proper request handler
switch ($action)
{
	case "view":
		vox_view_ideas(intval($_REQUEST["cat"]));
		break;
	case "list":
		vox_list_ideas(
			intval($_REQUEST["cat"]),
			intval($_REQUEST["startfrompage"]), 
			intval($_REQUEST["num"]), 
			intval($_REQUEST["onlyuser"]),
			intval($_REQUEST["onlyopen"]),
			intval($_REQUEST["onlystatus"]),
			trim($_REQUEST["sortorder"]),
			trim($_REQUEST["searchterm"]),
			intval($_REQUEST["fetchdesc"])
			);
		break;
	case "submit":
		vox_submit_idea(
			intval($_REQUEST["cat"]),
			trim($_REQUEST["title"]),
			trim($_REQUEST["desc"]),
			trim($_REQUEST["name"]),
			trim($_REQUEST["email"]));
		break;
	case "update":
		vox_update_idea(
			intval($_REQUEST["id"]),
			trim($_REQUEST["title"]),
			trim($_REQUEST["desc"]),
			trim($_REQUEST["name"]),
			trim($_REQUEST["email"]));
		break;	
	case "setstatus":
		vox_process_idea(
			intval($_REQUEST["id"]), 
			intval($_REQUEST["status"]), 
			trim($_REQUEST["comment"]), 
			intval($_REQUEST["sendupdate"]),
			true);
		break;
	case "vote": 
		vox_vote(
			intval($_REQUEST["id"]), 
			intval($_REQUEST["vote"]));
		break;
	case "delete": 
		vox_delete_idea(intval($_REQUEST["id"]), intval($_REQUEST["confirm"]));
		break;
	case "desc":
		vox_get_idea_description(intval($_REQUEST["id"]));
		break;
	case "move":
		vox_move_idea(intval($_REQUEST["id"]), 
			intval($_REQUEST["cat"]));
		break;
	case "cat_list":
		vox_list_categories();
		break;
	case "cat_submit":
		vox_add_category(
			trim($_REQUEST["title"]), 
			trim($_REQUEST["forumid"]));
		break;
	case "cat_update":
		vox_update_category(
			intval($_REQUEST["id"]), 
			trim($_REQUEST["title"]), 
			trim($_REQUEST["forumid"]));
		break;
	case "cat_delete":
		vox_delete_category(intval($_REQUEST["id"]), intval($_REQUEST["confirm"]));
		break;
	case "getideaform":
		vox_show_idea_form(intval($_REQUEST["id"]));
		break;
	case "getmoveform":
		vox_show_move_form(intval($_REQUEST["id"]));
		break;
	case "getstatusform":
		vox_show_status_form(
			intval($_REQUEST["id"]),
			intval($_REQUEST["status"])
			);
		break;
	case "getcatform":
		vox_show_cat_form(intval($_REQUEST["id"]));
		break;
	default: 
		vox_show_widget_box(intval($_REQUEST["cat"]));
}

include_once("site_specific/epilog.php");
?>
